<?php
/**
 * $Horde: jonah/content_edit.php,v 1.1 2006/01/07 03:46:42 chuck Exp $
 *
 * Copyright 1999-2006 Chuck Hagenbuch <chuck@horde.org>
 * Copyright 2003-2006 Mike Cochrane <mike@graftonhall.co.nz>
 * Copyright 2003-2006 Jan Schneider <jan@horde.org>
 *
 * See the enclosed file COPYING for license information (LGPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
 */

@define('JONAH_BASE', dirname(__FILE__));
require_once JONAH_BASE . '/lib/base.php';
require_once 'Horde/Block/Collection.php';
require_once 'Horde/Block/Layout/Manager.php';

// Get form values.
$col = (int)Util::getFormData('col');
$row = (int)Util::getFormData('row');
$action = Util::getFormData('action');
$edit_row = null;
$edit_col = null;

// Instantiate the blocks objects.
$blocks = &Horde_Block_Collection::singleton('portal');
$layout = &Horde_Block_Layout_Manager::singleton('mynews', $prefs->getValue('mynews_layout'));

// Handle requested actions.
switch ($action) {
case 'moveUp':
case 'moveDown':
case 'moveLeft':
case 'moveRight':
case 'expandUp':
case 'expandDown':
case 'expandLeft':
case 'expandRight':
case 'shrinkLeft':
case 'shrinkRight':
case 'shrinkUp':
case 'shrinkDown':
case 'removeBlock':
    $result = call_user_func(array(&$layout, $action), $row, $col);
    if (is_a($result, 'PEAR_Error')) {
        $notification->push($result);
    } else {
        $prefs->setValue('mynews_layout', $layout->serialize());
    }
    break;

// Save the changes made to a block.
case 'save':
// Save the changes made to a block and continue editing.
case 'save-resume':
    // Get requested block type.
    list($newapp, $newtype) = explode(':', Util::getFormData('app'));

    // Is this a new block?
    $new = false;
    if ($layout->isEmpty($row, $col) ||
        !$layout->rowExists($row) ||
        !$layout->colExists($col)) {
        // Check permissions.
        if (Horde::hasPermission('max_blocks') !== true &&
            Horde::hasPermission('max_blocks') <= $layout->count()) {
            $message = @htmlspecialchars(sprintf(_("You are not allowed to create more than %d blocks."), Horde::hasPermission('max_blocks')), ENT_COMPAT, NLS::getCharset());
            if (!empty($conf['hooks']['permsdenied'])) {
                $message = Horde::callHook('_perms_hook_denied', array('horde:max_blocks'), 'horde', $message);
            }
            $notification->push($message, 'horde.error', array('content.raw'));
            break;
        }

        $new = true;
        // Make sure there is somewhere to put it.
        $layout->addBlock($row, $col);
    }

    // Or an existing one?
    $exists = false;
    $changed = false;
    if (!$new) {
        // Get target block info.
        $info = $layout->getBlockInfo($row, $col);
        $exists = $layout->isBlock($row, $col);
        // Has a different block been selected?
        if ($exists &&
            ($info['app'] != $newapp ||
             $info['block'] != $newtype)) {
            $changed = true;
        }
    }

    if ($new || $changed) {
        // Change app or type.
        $info = array();
        $info['app'] = $newapp;
        $info['block'] = $newtype;
        $params = $blocks->getParams($newapp, $newtype);
        foreach ($params as $newparam) {
            $info['params'][$newparam] = $blocks->getDefaultValue($newapp, $newtype, $newparam);
        }
        $layout->setBlockInfo($row, $col, $info);
    } elseif ($exists) {
        // Change values.
        $layout->setBlockInfo($row, $col, array('params' => Util::getFormData('params', array())));
    }
    $prefs->setValue('mynews_layout', $layout->serialize());
    if ($action == 'save') {
        break;
    }

// Make a block the current block for editing.
case 'edit':
    $edit_row = $row;
    $edit_col = $col;
    break;
}

$title = _("My News :: Add Content");
require JONAH_TEMPLATES . '/common-header.inc';
echo '<div id="menu">' . Jonah::getMenu('string') . '</div>';
$notification->notify(array('listeners' => 'status'));
require $registry->get('templates', 'horde') . '/portal/edit.inc';
require $registry->get('templates', 'horde') . '/common-footer.inc';
