<?php

$block_name = _("Latest News");

/**
 * This class extends Horde_Block:: to provide the api to embed news
 * in other Horde applications.
 *
 * $Horde: jonah/lib/Block/latest.php,v 1.4 2006/01/02 17:50:50 jan Exp $
 *
 * Copyright 2002-2006 Roel Gloudemans <roel@gloudemans.info>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://cvs.horde.org/co.php/jonah/LICENSE.
 *
 * @author  Roel Gloudemans <roel@gloudemans.info>
 * @package Horde_Block
 */
class Horde_Block_Jonah_latest extends Horde_Block {

    var $_app = 'jonah';

    function Horde_Block_Jonah_latest($params = array())
    {
        parent::Horde_Block($params);
        @define('JONAH_BASE', dirname(__FILE__) . '/../..');
        @define('JONAH_TEMPLATES', JONAH_BASE . '/templates');
        require_once JONAH_BASE . '/lib/Jonah.php';
        require_once JONAH_BASE . '/lib/News.php';
    }

    function _params()
    {
        global $conf;

        require JONAH_BASE . '/config/conf.php';

        $params['source'] = array('name' => _("News Source"),
                                  'type' => 'enum',
                                  'values' => array());

        $news = &Jonah_News::singleton();
        $channels = $news->getChannels(JONAH_INTERNAL_CHANNEL);
        foreach ($channels as $channel) {
            $params['source']['values'][$channel['channel_id']] = $channel['channel_name'];
        }
        natcasesort($params['source']['values']);

        return $params;
    }

    function _title()
    {
        $news = &Jonah_News::singleton();
        $channel = $news->getChannel($this->_params['source']);

        return sprintf(_("Latest news from %s"), $channel['channel_name']);
    }

    function _content()
    {
        if (empty($this->_params['source'])) {
            return _("No channel specified.");
        }

        $news = &Jonah_News::singleton();

        $story_id = $news->getLatestStoryId($this->_params['source']);
        $story    = $news->getStory($this->_params['source'], $story_id);

        if (is_a($story, 'PEAR_Error')) {
            $notification->push(sprintf(_("Error fetching story: %s"), $story->getMessage()), 'horde.warning');
        }

        $story['story_title'] = htmlspecialchars($story['story_title']);
        $story['story_desc'] = htmlspecialchars($story['story_desc']);

        if ($story['story_body_type'] == 'text') {
            require_once 'Horde/Text/Filter.php';
            $story['story_body'] = Text_Filter::filter($story['story_body'], 'text2html', array('parselevel' => TEXT_HTML_MICRO, 'class' => null));
        }

        require_once 'Horde/Template.php';
        $template = &new Horde_Template();
        $template->set('story', $story, true);

        return $template->fetch(JONAH_TEMPLATES . '/stories/view.html');
    }

}
