<?php
/**
 * Script to add/edit stories.
 *
 * Copyright 2003-2006 Marko Djukic <marko@oblo.com>
 * Copyright 2003-2006 Chuck Hagenbuch <chuck@horde.org>
 *
 * $Horde: jonah/stories/edit.php,v 1.33 2006/01/08 00:59:55 chuck Exp $
 *
 * See the enclosed file LICENSE for license information (BSD). If you did not
 * receive this file, see http://cvs.horde.org/co.php/jonah/LICENSE.
 */

@define('JONAH_BASE', dirname(__FILE__) . '/..');
require_once JONAH_BASE . '/lib/base.php';
require_once JONAH_BASE . '/lib/News.php';
require_once 'Horde/Form.php';
require_once 'Horde/Variables.php';
require_once 'Horde/Form/Action.php';

$news = &Jonah_News::singleton();

/* Set up the form variables. */
$vars = &Variables::getDefaultVariables();
$channel_id = $vars->get('channel_id');

/* Fetch the channel details, needed for later and to check if valid
 * channel has been requested. */
$channel = $news->isChannelEditable($channel_id);
if (is_a($channel, 'PEAR_Error')) {
    $notification->push(sprintf(_("Story editing failed: %s"), $channel->getMessage()), 'horde.error');
    $url = Horde::applicationUrl('channels/index.php', true);
    header('Location: ' . $url);
    exit;
}

/* Check permissions. */
if (!Jonah::checkPermissions(Jonah::typeToPermName($channel['channel_type']), PERMS_EDIT, $channel_id)) {
    $notification->push(_("You are not authorised for this action."), 'horde.warning');
    Horde::authenticationFailureRedirect();
}

$story_id = $vars->get('story_id');

/* Set up some variables. */
$formname = $vars->get('formname');

$form = &Horde_Form::singleton('', $vars);
$action = &Horde_Form_Action::factory('submit');

/* Check if a story is being edited. */
if ($story_id && !$form->isSubmitted()) {
    $story = $news->getStory($channel_id, $story_id);
    $vars = &new Variables($story);
}

$title = ($story_id) ? _("Edit Story") : _("Add New Story");

/* Set up the form. */
$form->setTitle($title);
$form->setButtons(_("Save"), true);
$form->addHidden('', 'channel_id', 'int', false);
$form->addHidden('', 'story_id', 'int', false);
$form->addVariable(_("Story Title (Headline)"), 'story_title', 'text', true);
$form->addVariable(_("Short Description"), 'story_desc', 'longtext', true, false, null, array(2, 80));
$form->addVariable(_("Publish Now?"), 'story_release_now', 'boolean', false);
$form->addVariable(_("Or publish on this date:"), 'story_release_date', 'monthDayYear', false, false, _("Note: this story won't be delivered to distribution lists automatically if this time is in the future."));
$form->addVariable('', 'story_release_time', 'hourMinuteSecond', false);
$v = &$form->addVariable(_("Story body type"), 'story_body_type', 'enum', false, false, null, array(Jonah::getBodyTypes()));
$v->setAction($action);
$v->setOption('trackchange', true);

/* If no body type specified, default to one. */
$body_type = $vars->get('story_body_type');
if (empty($body_type)) {
    $body_type = Jonah::getDefaultBodyType();
    $vars->set('story_body_type', $body_type);
}

/* If no date specified, default to now. */
$release = $vars->get('story_release_date');
if (empty($release)) {
    $vars->set('story_release_date', time());
    $vars->set('story_release_time', time());
}

/* Set up the fields according to what the type of body requested. */
if ($body_type == 'text') {
    $form->addVariable(_("Full Story Text"), 'story_body', 'longtext', false, false, null, array(15, 80));
} elseif ($body_type == 'richtext') {
    $form->addVariable(_("Full Story Text"), 'story_body', 'longtext', false, false, null, array(20, 80, array('rte')));
}

/* Only show URL insertion if it has been enabled in config. */
if (in_array('links', $conf['news']['story_types'])) {
    $form->addVariable(_("Story URL"), 'story_url', 'text', false, false, _("If you enter a URL without a full story text, clicking on the story will send the reader straight to the URL, otherwise it will be shown at the end of the full story."));
}

if ($form->validate($vars)) {
    $form->getInfo($vars, $info);
    $save = $news->saveStory($info);
    if (is_a($save, 'PEAR_Error')) {
        $notification->push(sprintf(_("There was an error saving the story: %s"), $save->getMessage()), 'horde.error');
    } else {
        $notification->push(sprintf(_("The story \"%s\" has been saved."), $info['story_title']), 'horde.success');
        $url = Horde::applicationUrl('stories/index.php', true);
        $url = Util::addParameter($url, 'channel_id', $channel_id, false);
        header('Location: ' . $url);
        exit;
    }
}

/* Render the form. */
require_once 'Horde/Form/Renderer.php';
$renderer = &new Horde_Form_Renderer();
$main = Util::bufferOutput(array($form, 'renderActive'), $renderer, $vars, 'edit.php', 'post');

$template = &new Horde_Template();
$template->set('main', $main);
$template->set('menu', Jonah::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

require JONAH_TEMPLATES . '/common-header.inc';
echo $template->fetch(JONAH_TEMPLATES . '/main/main.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
